@@ -2,7 +2,7 @@ from examples.langchain_example.langchain_google_genai import basic_google_genai
 from .basic import basic_app, rag, load_and_split
 from langtrace_python_sdk import with_langtrace_root_span
 
-from .groq_example import groq_basic, groq_streaming
+from .groq_example import groq_basic, groq_tool_choice, groq_streaming
 from .langgraph_example_tools import basic_graph_tools
 
 
@@ -20,3 +20,5 @@ class GroqRunner:
     @with_langtrace_root_span("Groq")
     def run(self):
         groq_streaming()
+        groq_basic()
+        groq_tool_choice()
